@@ -74,12 +74,11 @@ int bvc_clear_route_history_v6(BVS_CMD_PARAM *prm)
 
         if (node == NULL) {
                 if (cnode == NULL) {
-                        cnode = NULL;
                         rthist_clean_v6 = RTHIST_NOTCLEANING;
                         curclno = -1;
                         return(BVS_CNT_END);
                 } else {
-                        time(&cleaned_time);
+                        time(&cleaned_time_v6);
                         cnode = NULL;
                         rthist_clean_v6 = RTHIST_NOTCLEANING;
                         curclno = -1;
