@@ -4,7 +4,7 @@
 /*                                                              */
 /* IRRd Interface                                               */
 /****************************************************************/
-/* irrdif.c,v 1.10 2008/06/26 05:24:08 kuniaki Exp */
+/* irrdif.c,v 1.12 2010/11/14 09:33:57 kuniaki Exp */
 
 /*
  * Copyright (c) 2006 Atelier Mahoroba
@@ -169,9 +169,11 @@ int close_irr()
 {
 	static char fincmd[] = "!q\n";
 
-	sockwrite(irrsock, fincmd, 3);
-	close(irrsock);
-	irrsock = 0;
+	if (irrsock != 0) {
+		sockwrite(irrsock, fincmd, 3);
+		close(irrsock);
+		irrsock = 0;
+	}
 }
 
 int irr_search_route(struct in_addr *in, u_short plen)
@@ -195,16 +197,18 @@ int sread(char *buf, int len)
         int    		rel;
 	struct timeval	tval;
 	fd_set		irrset;
+	int		readzerocnt;
 
 	tval.tv_sec  = IRR_SEARCH_TIMEOUT;
 	tval.tv_usec = 0;
         cnt = 0;
+	readzerocnt = 0;
 	if (irrsock == 0) return(0);
         bzero(buf, len);
         while(cnt < len) {
 		FD_ZERO(&irrset);
 		FD_SET(irrsock, &irrset);
-		if (select(FD_SETSIZE, NULL, &irrset, NULL, &tval) < 0) {
+		if (select(FD_SETSIZE, &irrset, NULL, NULL, &tval) < 0) {
 			if (errno == EINTR) {
 				printf("Select Return Code EINTR on irrdata\n");
 				continue;
@@ -216,6 +220,16 @@ int sread(char *buf, int len)
 		}
 		if (FD_ISSET(irrsock, &irrset)) {
                 	rel = read(irrsock, (char *)(buf + cnt), (len-cnt));
+			if (rel == 0) {
+				if (readzerocnt > 100) {
+					/* read fail */
+					return(0);
+				} else {
+					readzerocnt++;
+				}
+			} else {
+				readzerocnt = 0;
+			}
                 	cnt += rel;
 #ifdef DEBUG
                 	printf("DEBUG: Reading %d/%d/%d\n",rel,cnt,len);
@@ -250,7 +264,7 @@ int getcontrol(char *type)
         while(1) {
 		FD_ZERO(&irrset);
 		FD_SET(irrsock, &irrset);
-		if (select(FD_SETSIZE, NULL, &irrset, NULL, &tval) < 0) {
+		if (select(FD_SETSIZE, &irrset, NULL, NULL, &tval) < 0) {
 			if (errno == EINTR) {
 				printf("Select Return Code EINTR on irr\n");
 				continue;
@@ -260,8 +274,16 @@ int getcontrol(char *type)
 				"Select Error on IRR Check\n");
 			return(0);
 		}
+#ifdef DEBUG
+		printf("DEBUG: irrif.c: getcontrol: select return = %d\n",ret);
+#endif
 		if (FD_ISSET(irrsock, &irrset)) {
-	                read(irrsock, &c, 1);
+	                if (read(irrsock, &c, 1) == 0) {
+				/* Socket Broken? */
+				close(irrsock);
+				irrsock = 0;
+				return(0);
+			}
                 	if (c == '\n') break;
                 	if (c == '\r') break;
                 	if (cnt == -1) break;
@@ -625,9 +647,18 @@ int irrchk_r_list(R_LIST *rlist)
 			free(bufptr);
 			bufptr = NULL;
 		}
+#ifdef DEBUG
+		else {
+			printf("DEBUG: IRR Cached : %08X/%d\n",
+						ri->prefix, ri->length);
+		}
+#endif
+			
 			
 		rptr = rptr->next;
 	}
+
+	return(0);
 }
 
 void walk_bgp_chk_irr()
@@ -660,6 +691,13 @@ void walk_bgp_chk_irr()
 	if (node != NULL) {
 		irrchk_r_list(node->rinfo);
 	}
+
+	/* Socket Check */
+	if (irrsock == 0) {
+		pr_log2(VLOG_GLOB, LOG_ALL, ON, "IRR Connection Fail\n");
+		node  = NULL;
+	}
+
 	if (node == NULL) {
 		if (cnode == NULL) {
 			cnode = node;
