@@ -38,6 +38,12 @@
 #include <errno.h>
 #endif
 
+RADIX_T *radix_top;
+u_long  nodes;
+u_long  routes;
+u_long  prefixes;
+
+
 /*** Local Variables ***/
 int	rtclear_id;
 
@@ -614,6 +620,9 @@ u_long delete_peer_route(RADIX_T **cnode, int pn)
 			while(1) {
 				bnode = node;
 				node = node->upleaf;
+				/*** Debug 2008/06/18 ***/
+				if (node == NULL) break;
+
 				if ((bnode->r_leaf != NULL) && 
 				    (bnode->l_leaf != NULL)) {
 					break;
