@@ -229,7 +229,7 @@ void pr_v6route(ROUTE_INFO_V6 *routep, int pn)
 
 void pr_update(int pn)
 {
-	char 		*ptr, *ptr2;
+	unsigned char 	*ptr, *ptr2;
 	char		cbuf[128], *cp;
 	int		pt2;
 	struct in_addr 	inaddr;
@@ -496,7 +496,7 @@ void pr_update(int pn)
 					strcat(logstr, cbuf);
 				  }
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
-				  length = *(ptr+ptmp);
+				  length = *(unsigned char *)(ptr+ptmp);
 				  ptmp++;
 				  sprintf(logstr, "%d\n", length);
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
@@ -742,7 +742,7 @@ void pr_update(int pn)
 					strcat(logstr, cbuf);
 				  }
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
-				  length = *(ptr+ptmp);
+				  length = *(unsigned char *)(ptr+ptmp);
 				  ptmp++;
 				  sprintf(logstr, "%d\n", length);
 				  pr_log(VLOG_UPAT, pn, logstr, OFF);
